.. django-counter-field documentation master file, created by
   sphinx-quickstart on Thu Dec 26 02:26:21 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-counter-field's documentation!
================================================

Contents:

.. toctree::
   :maxdepth: 4

   django_counter_field.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

